@@ -1,7 +1,7 @@
 /*
  *  PresetControllerView.h
  *
- *  Copyright (c) 2001-2012 Nick Dowell
+ *  Copyright (c) 2001-2019 Nick Dowell
  *
  *  This file is part of amsynth.
  *
@@ -22,16 +22,16 @@
 #ifndef _PRESETCONTROLLERVIEW_H
 #define _PRESETCONTROLLERVIEW_H
 
-#include <gtkmm.h>
+#include <gtk/gtk.h>
 
 class PresetController;
-class VoiceAllocationUnit;
 
-class PresetControllerView : public Gtk::HBox { public:
-	static PresetControllerView * create(VoiceAllocationUnit *voiceAllocationUnit);
-	virtual void setPresetController(PresetController *presetController) = 0;
+class PresetControllerView { public:
+	static PresetControllerView * instantiate(PresetController *presetController);
     virtual void update() = 0;
-    virtual int getAuditionNote() = 0;
+    virtual unsigned char getAuditionNote() = 0;
+	virtual GtkWidget * getWidget() = 0;
+    virtual ~PresetControllerView() {}
 };
 
 #endif
