@@ -28,9 +28,13 @@
 
 G_BEGIN_DECLS
 
+#define DEFAULT_SCALING 0
+
 GtkWidget *
 editor_pane_new(void *synthesizer, GtkAdjustment **adjustments, gboolean is_plugin, int scaling_factor);
 
+int default_scaling_factor(void);
+
 void modal_midi_learn(Param param_index);
 
 G_END_DECLS
