@@ -1,7 +1,7 @@
 /*
  *  Preset.h
  *
- *  Copyright (c) 2001-2012 Nick Dowell
+ *  Copyright (c) 2001-2022 Nick Dowell
  *
  *  This file is part of amsynth.
  *
@@ -22,20 +22,21 @@
 #ifndef _PRESET_H
 #define _PRESET_H
 
-#ifdef __cplusplus
-
 #include "Parameter.h"
 
 #include <sstream>
 #include <string>
-#include <vector>
 
 
 class Preset
 {
 public:
 	Preset(const std::string name = "");
-					
+
+	Preset(const Preset& other);
+
+	~Preset();
+
 	Preset&			operator =		(const Preset& p);
 	
 	bool			isEqual			(const Preset &);
@@ -47,8 +48,6 @@ public:
 	Parameter&		getParameter	(const int no) { return mParameters[no]; };
 	const Parameter& getParameter	(const int no) const { return mParameters[no]; };
 	
-	size_t			ParameterCount	() const { return mParameters.size(); }
-	
     void			randomise		();
     
     void			AddListenerToAll(UpdateListener*);
@@ -65,21 +64,7 @@ public:
 
 private:
     std::string				mName;
-	std::vector<Parameter>	mParameters;
-	Parameter				nullparam{"null"};
+	Parameter				*mParameters;
 };
 
 #endif
-
-#ifdef __cplusplus
-extern "C" {
-#endif
-
-void get_parameter_properties(int parameter_index, double *minimum, double *maximum, double *default_value, double *step_size);
-
-#ifdef __cplusplus
-}
-#endif
-
-#endif
-
