@@ -1,7 +1,7 @@
 /*
  *  main.h
  *
- *  Copyright (c) 2001-2012 Nick Dowell
+ *  Copyright (c) 2001-2016 Nick Dowell
  *
  *  This file is part of amsynth.
  *
@@ -22,18 +22,30 @@
 #ifndef _amsynth_main_h
 #define _amsynth_main_h
 
+#include "types.h"
+
 #ifdef __cplusplus
+#include <vector>
 extern "C" {
 #endif
 
 extern void amsynth_save_bank(const char *filename);
 extern void amsynth_load_bank(const char *filename);
+
 extern int  amsynth_load_tuning_file(const char *filename);
+
 extern int  amsynth_get_preset_number();
 extern void amsynth_set_preset_number(int preset_no);
+
 extern void amsynth_midi_input(unsigned char status, unsigned char data1, unsigned char data2);
 
 #ifdef __cplusplus
+
+extern void amsynth_audio_callback(
+        float *buffer_l, float *buffer_r, unsigned num_frames, int stride,
+        const std::vector<amsynth_midi_event_t> &midi_in,
+        std::vector<amsynth_midi_cc_t> &midi_out);
+
 }
 #endif
 
